# Generated by roxygen2: do not edit by hand

export(corpus_analytics)
export(generate_shams)
export(prep_dyads)
export(read_1file)
export(read_dyads)
export(summarize_dyads)
importFrom(DescTools,AUC)
importFrom(dplyr,across)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,consecutive_id)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,lag)
importFrom(dplyr,left_join)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,na_if)
importFrom(dplyr,rename)
importFrom(dplyr,rename_at)
importFrom(dplyr,rename_with)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(httr,GET)
importFrom(magrittr,"%>%")
importFrom(purrr,map_dfr)
importFrom(rlang,":=")
importFrom(rlang,sym)
importFrom(stats,cor.test)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(stringi,stri_replace_all_fixed)
importFrom(stringi,stri_replace_all_regex)
importFrom(stringr,str_c)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_squish)
importFrom(stringr,str_subset)
importFrom(stringr,str_trim)
importFrom(textstem,lemmatize_strings)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,fill)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,separate)
importFrom(tidyr,separate_rows)
importFrom(tidyselect,all_of)
importFrom(tidyselect,any_of)
importFrom(tidyselect,contains)
importFrom(tidyselect,ends_with)
importFrom(tidyselect,everything)
importFrom(tidyselect,starts_with)
importFrom(tidyselect,where)
importFrom(tools,R_user_dir)
importFrom(utils,download.file)
importFrom(utils,globalVariables)
importFrom(utils,read.csv)
importFrom(utils,select.list)
importFrom(utils,tail)
importFrom(zoo,na.approx)
