#' @importFrom utils globalVariables
NULL

utils::globalVariables(
  c("CA_orig_stops",
    "clean_me",
    "clean_dyads",
    "cor",
    "df",
    "df_prep",
    "df_read",
    "df_summarize",
    "Exchanges",
    "Exchange_Count",
    'Event_ID',
    "freq_lg10",
    "letter_count",
    "lex_freqlg10",
    "lex_n_morphemes",
    "lookup_Jul25",
    "measure",
    "MIT_Stops",
    "morpheme_count",
    "n_participants",
    "participant_var",
    'Participant_ID',
    "Participant_Pair",
    "phon_n_lett",
    "phon_nsyll",
    "reshaped",
    "score",
    "setNames",
    "SMART_stops",
    "stdev",
    "sumdat",
    "sumdat_only",
    "summary_statistic",
    'switch_mark',
    "syllable_count",
    "Temple_stops25",
    "Text_Clean",
    "Text_Prep",
    "Text_Raw",
    "Turn_Count",
    "value",
    "word",
    "words_per_turn_clean",
    "words_per_turn_raw"
  ))
